==> haskell-hledger-lib-1.10-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.10
id: hledger-lib-1.10-94jW9gp0AaiHdeaJYEx9Sw
key: hledger-lib-1.10-94jW9gp0AaiHdeaJYEx9Sw
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 2a067cf00c5f73d8e00796d4081b60cf
exposed: True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.AutoTransaction
    Hledger.Data.Commodity Hledger.Data.Dates Hledger.Data.Journal
    Hledger.Data.Ledger Hledger.Data.MarketPrice Hledger.Data.Period
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.Types Hledger.Query
    Hledger.Read Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.JournalReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.BalanceHistoryReport Hledger.Reports.BalanceReport
    Hledger.Reports.BudgetReport Hledger.Reports.EntriesReport
    Hledger.Reports.MultiBalanceReports Hledger.Reports.PostingsReport
    Hledger.Reports.ReportOptions Hledger.Reports.ReportTypes
    Hledger.Reports.TransactionsReports Hledger.Utils
    Hledger.Utils.Color Hledger.Utils.Debug Hledger.Utils.Parse
    Hledger.Utils.Regex Hledger.Utils.String Hledger.Utils.Test
    Hledger.Utils.Text Hledger.Utils.Tree Hledger.Utils.UTF8IOCompat
    Text.Tabular.AsciiWide
hidden-modules: Text.Megaparsec.Custom Paths_hledger_lib
import-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hledger-lib-1.10
hs-libraries: HShledger-lib-1.10-94jW9gp0AaiHdeaJYEx9Sw
depends:
    Decimal-0.5.1-CoPtTI9YM363muqQEsVUfq
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG array-0.5.2.0
    base-4.11.1.0 base-compat-batteries-0.10.1-8OmQKIeRUfc9d5uOba9tfI
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    cmdargs-0.10.20-DuSx78jNQymI404wla4i2p containers-0.5.11.0
    csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0 deepseq-1.4.3.0
    directory-1.3.1.5 extra-1.6.9-KIq7mML6iLyAN2GFgLL0Nq filepath-1.4.2
    hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg
    megaparsec-6.5.0-8TBK5RCwS02DkcrV4N4r6X mtl-2.2.2
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu parsec-3.1.13.0
    parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
    pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: Decimal-0.5.1-CoPtTI9YM363muqQEsVUfq=9c4315ba461f59a00d19f28143886add
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-batteries-0.10.1-8OmQKIeRUfc9d5uOba9tfI=12839091e76cdf609072f8ca1e680cd5
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=a51a70da70fea2284f20b4e90220083e
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m=0f78428cabdbdd37393a6050b968cc06
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             extra-1.6.9-KIq7mML6iLyAN2GFgLL0Nq=cfd74dad553a0b4816454153cfb1f2be
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=064de8ddacfdc86a91d65bbec6437a86
             megaparsec-6.5.0-8TBK5RCwS02DkcrV4N4r6X=fa3015733b18421365ca6f1b1a98154c
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci=ef2596da1199b6931b4ad98e4f5de95e
             pretty-show-1.7-8bRRNOzyOi99X2ErRO7kao=6113716a5efda4345adf3bac9f3dc9b0
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=5e8070c089035e31a54af0f52dd81fff
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY=60e37e424f769ddf753ab1cb80d23363
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx=4df606263fcaf6694600613b0076dbaf
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hledger-lib-1.10-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hledger-lib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hledger-lib
version: 1.10
id: hledger-lib-1.10-69bAWlO4xGUInu3rIyKBe6
key: hledger-lib-1.10-69bAWlO4xGUInu3rIyKBe6
license: GPL-3.0-only
maintainer: Simon Michael <simon@joyful.com>
author: Simon Michael <simon@joyful.com>
stability: stable
homepage: http://hledger.org
synopsis: Core data types, parsers and functionality for the hledger accounting tools
description:
    This is a reusable library containing hledger'\''s core functionality.
    .
    hledger is a cross-platform program for tracking money, time, or
    any other commodity, using double-entry accounting and a simple,
    editable file format. It is inspired by and largely compatible
    with ledger(1).  hledger provides command-line, curses and web
    interfaces, and aims to be a reliable, practical tool for daily
    use.
category: Finance
abi: 5a92b474bfa0f58521989ba6963d00b2
exposed: True
exposed-modules:
    Hledger Hledger.Data Hledger.Data.Account Hledger.Data.AccountName
    Hledger.Data.Amount Hledger.Data.AutoTransaction
    Hledger.Data.Commodity Hledger.Data.Dates Hledger.Data.Journal
    Hledger.Data.Ledger Hledger.Data.MarketPrice Hledger.Data.Period
    Hledger.Data.Posting Hledger.Data.RawOptions
    Hledger.Data.StringFormat Hledger.Data.Timeclock
    Hledger.Data.Transaction Hledger.Data.Types Hledger.Query
    Hledger.Read Hledger.Read.Common Hledger.Read.CsvReader
    Hledger.Read.JournalReader Hledger.Read.TimeclockReader
    Hledger.Read.TimedotReader Hledger.Reports
    Hledger.Reports.BalanceHistoryReport Hledger.Reports.BalanceReport
    Hledger.Reports.BudgetReport Hledger.Reports.EntriesReport
    Hledger.Reports.MultiBalanceReports Hledger.Reports.PostingsReport
    Hledger.Reports.ReportOptions Hledger.Reports.ReportTypes
    Hledger.Reports.TransactionsReports Hledger.Utils
    Hledger.Utils.Color Hledger.Utils.Debug Hledger.Utils.Parse
    Hledger.Utils.Regex Hledger.Utils.String Hledger.Utils.Test
    Hledger.Utils.Text Hledger.Utils.Tree Hledger.Utils.UTF8IOCompat
    Text.Tabular.AsciiWide
hidden-modules: Text.Megaparsec.Custom Paths_hledger_lib
import-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/hledger-lib-1.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hledger-lib-1.10
hs-libraries: HShledger-lib-1.10-69bAWlO4xGUInu3rIyKBe6
depends:
    Decimal-0.5.1-25sqKICsg5dGEytWuY5eIU
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8 array-0.5.2.0
    base-4.11.1.0 base-compat-batteries-0.10.1-AUs9ldGqZdKKvtSVvl9E7e
    blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug bytestring-0.10.8.2
    cmdargs-0.10.20-DuSx78jNQymI404wla4i2p containers-0.5.11.0
    csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m
    data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0 deepseq-1.4.3.0
    directory-1.3.1.5 extra-1.6.9-KIq7mML6iLyAN2GFgLL0Nq filepath-1.4.2
    hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg
    megaparsec-6.5.0-4fb3qBlRsMw28WLKMZ44M9 mtl-2.2.2
    old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu parsec-3.1.13.0
    parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
    pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur
    split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG
    tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx
    utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8
abi-depends: Decimal-0.5.1-25sqKICsg5dGEytWuY5eIU=5d7a9c27d830d48766cd4f1c39ba1ec1
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8=60434811d26166e1bacacf0138207cc4
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-batteries-0.10.1-AUs9ldGqZdKKvtSVvl9E7e=842c864979107fe066d13bf08dc82f4d
             blaze-markup-0.8.2.1-FFkiru1HsegAfMrnqJMDug=18a52ecde9bf04c66bdf9a0cefc08348
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             cmdargs-0.10.20-DuSx78jNQymI404wla4i2p=a51a70da70fea2284f20b4e90220083e
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             csv-0.1.2-EpTL7zD0nY4Lq2oA3vrN2m=0f78428cabdbdd37393a6050b968cc06
             data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0=df69bf1546f6b4e11e877584feeeb61a
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             extra-1.6.9-KIq7mML6iLyAN2GFgLL0Nq=cfd74dad553a0b4816454153cfb1f2be
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hashtables-1.2.3.1-FwvkrjNnnglEJJXpMCqokg=064de8ddacfdc86a91d65bbec6437a86
             megaparsec-6.5.0-4fb3qBlRsMw28WLKMZ44M9=ba9c0b60538ce8cc8045f910869f466c
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             old-time-1.1.0.3-ISACJ3jTIVREs8CzPwsoWu=bc059b0124ba79adaeef6204d1984335
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
             parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci=ef2596da1199b6931b4ad98e4f5de95e
             pretty-show-1.8.1-7H0L2aT0WSVIsk7RM7bmlH=80041e6bd348b4048d884d7cb6e8d993
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=5e8070c089035e31a54af0f52dd81fff
             safe-0.3.17-HEmZRpXGD3s2ywM3rHJ1ur=f24d7708a3245ecd805ff7d598d8872c
             split-0.2.3.3-DYHuRk05Zl3FsXrGVgC4fG=ea4c73c7e93df299ddc7c8e477e863d6
             tabular-0.2.2.7-HF2IJKR6TJrGdD2ud3QwlY=60e37e424f769ddf753ab1cb80d23363
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             uglymemo-0.1.0.1-L9PTRXpxSIOFxxvyPl9dNx=4df606263fcaf6694600613b0076dbaf
             utf8-string-1.0.1.1-LRSjvSC6FZkKPp48Qszoj8=2191a818a7f61b012f58bd96949826c6
haddock-interfaces: /usr/share/doc/haskell-hledger-lib/html/hledger-lib.haddock
haddock-html: /usr/share/doc/haskell-hledger-lib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
